@@ -3,10 +3,9 @@
 
 namespace Icinga\Module\Doc\Renderer;
 
-require_once 'Parsedown/Parsedown.php';
-
 use DOMDocument;
 use DOMXPath;
+use Icinga\Module\Doc\DocSection;
 use Parsedown;
 use RecursiveIteratorIterator;
 use Icinga\Data\Tree\SimpleTree;
@@ -65,7 +64,8 @@ class DocSectionRenderer extends DocRenderer
             $filter = new DocSectionFilterIterator($tree->getIterator(), $chapter);
             if ($filter->isEmpty()) {
                 throw new ChapterNotFoundException(
-                    mt('doc', 'Chapter %s not found'), $chapter
+                    mt('doc', 'Chapter %s not found'),
+                    $chapter
                 );
             }
             parent::__construct(
@@ -193,7 +193,7 @@ class DocSectionRenderer extends DocRenderer
         $path = $this->getView()->getHelper('Url')->url(
             array_merge(
                 array(
-                    'image' => $img->getAttribute('src')
+                    'image' => trim($img->getAttribute('src'))
                 ),
                 $this->urlParams
             ),
@@ -202,7 +202,7 @@ class DocSectionRenderer extends DocRenderer
             false
         );
         $url = $this->getView()->url($path);
-        /** @var \Icinga\Web\Url $url */
+        /** @var Url $url */
         $img->setAttribute('src', $url->getAbsoluteUrl());
         return substr_replace($doc->saveXML($img), '', -2, 1);  // Replace '/>' with '>'
     }
@@ -219,7 +219,7 @@ class DocSectionRenderer extends DocRenderer
         if (($chapter = $this->tree->getNode($this->decodeAnchor($match['chapter']))) === null) {
             return $match[0];
         }
-        /** @var \Icinga\Module\Doc\DocSection $section */
+        /** @var DocSection $section */
         $path = $this->getView()->getHelper('Url')->url(
             array_merge(
                 $this->urlParams,
@@ -232,7 +232,7 @@ class DocSectionRenderer extends DocRenderer
             false
         );
         $url = $this->getView()->url($path);
-        /** @var \Icinga\Web\Url $url */
+        /** @var Url $url */
         return sprintf(
             '<a %s%shref="%s"',
             strlen($match['attribs']) ? trim($match['attribs']) . ' ' : '',
@@ -253,7 +253,7 @@ class DocSectionRenderer extends DocRenderer
         if (($section = $this->tree->getNode($this->decodeAnchor($match['section']))) === null) {
             return $match[0];
         }
-        /** @var \Icinga\Module\Doc\DocSection $section */
+        /** @var DocSection $section */
         $path = $this->getView()->getHelper('Url')->url(
             array_merge(
                 $this->urlParams,
@@ -266,7 +266,7 @@ class DocSectionRenderer extends DocRenderer
             false
         );
         $url = $this->getView()->url($path);
-        /** @var \Icinga\Web\Url $url */
+        /** @var Url $url */
         $url->setAnchor($this->encodeAnchor($section->getId()));
         return sprintf(
             '<a %s%shref="%s"',
