@@ -3,18 +3,24 @@
 
 namespace Icinga\Module\Monitoring\Backend\Ido\Query;
 
+use Icinga\Data\Filter\Filter;
+use Icinga\Data\Filter\FilterExpression;
+
 /**
  * Query for host downtime end history records
  */
 class ServicedowntimeendhistoryQuery extends ServicedowntimestarthistoryQuery
 {
-    public function isTimestamp($field)
+    protected function requireFilterColumns(Filter $filter)
     {
-        if (! parent::isTimestamp($field)) {
-            return $field === 'sdh.actual_end_time';
+        if ($filter instanceof FilterExpression && $filter->getColumn() === 'timestamp') {
+            $this->requireColumn('timestamp');
+            $filter->setColumn('sdh.actual_end_time');
+            $filter->setExpression($this->timestampForSql($this->valueToTimestamp($filter->getExpression())));
+            return null;
         }
 
-        return true;
+        return parent::requireFilterColumns($filter);
     }
 
     /**
@@ -23,7 +29,9 @@ class ServicedowntimeendhistoryQuery extends ServicedowntimestarthistoryQuery
     protected function joinBaseTables()
     {
         parent::joinBaseTables(true);
-        $this->select->where("sdh.actual_end_time > '1970-01-02 00:00:00'");
+        $this->select->where(
+            "sdh.actual_end_time > '1970-01-02 00:00:00' AND sdh.was_started = 1 AND sdh.was_cancelled = 0"
+        );
         $this->columnMap['downtimehistory']['type'] = "('dt_end')";
         $this->columnMap['downtimehistory']['timestamp'] = str_replace(
             'actual_start_time',
