@@ -23,6 +23,13 @@ class AuthBackendPage extends Form
      */
     protected $config;
 
+    /**
+     * Default values for the subform's elements suggested by a previous step
+     *
+     * @var string[]
+     */
+    protected $suggestions = array();
+
     /**
      * Initialize this page
      */
@@ -61,7 +68,15 @@ class AuthBackendPage extends Form
             $this->addSkipValidationCheckbox();
         }
 
-        if ($this->config['type'] === 'db') {
+        $backendForm = null;
+        if (! isset($this->config) || $this->config['type'] === 'external') {
+            $backendForm = new ExternalBackendForm();
+            $backendForm->create($formData);
+            $this->addDescription($this->translate(
+                'You\'ve chosen to authenticate using a web server\'s mechanism so it may be necessary'
+                . ' to adjust usernames before any permissions, restrictions, etc. are being applied.'
+            ));
+        } elseif ($this->config['type'] === 'db') {
             $this->setRequiredCue(null);
             $backendForm = new DbBackendForm();
             $backendForm->setRequiredCue(null);
@@ -72,12 +87,16 @@ class AuthBackendPage extends Form
             ));
         } elseif ($this->config['type'] === 'ldap') {
             $type = null;
-            if (! isset($formData['type']) && isset($formData['backend'])) {
-                $type = $formData['backend'];
-                $formData['type'] = $type;
+            if (! isset($formData['type'])) {
+                if (isset($formData['backend'])) {
+                    $formData['type'] = $type = $formData['backend'];
+                } elseif (isset($this->suggestions['backend'])) {
+                    $formData['type'] = $type = $this->suggestions['backend'];
+                }
             }
 
             $backendForm = new LdapBackendForm();
+            $backendForm->setSuggestions($this->suggestions);
             $backendForm->setResources(array($this->config['name']));
             $backendForm->create($formData);
             $backendForm->getElement('resource')->setIgnore(true);
@@ -103,13 +122,6 @@ class AuthBackendPage extends Form
                     'value'             => $type
                 )
             );
-        } else { // $this->config['type'] === 'external'
-            $backendForm = new ExternalBackendForm();
-            $backendForm->create($formData);
-            $this->addDescription($this->translate(
-                'You\'ve chosen to authenticate using a web server\'s mechanism so it may be necessary'
-                . ' to adjust usernames before any permissions, restrictions, etc. are being applied.'
-            ));
         }
 
         $backendForm->getElement('name')->setValue('icingaweb2');
@@ -144,14 +156,18 @@ class AuthBackendPage extends Form
             return false;
         }
 
-        if ($this->config['type'] === 'ldap' && (! isset($data['skip_validation']) || $data['skip_validation'] == 0)) {
-            $self = clone $this;
-            $self->getSubForm('backend_form')->getElement('resource')->setIgnore(false);
-            $inspection = UserBackendConfigForm::inspectUserBackend($self);
-            if ($inspection && $inspection->hasError()) {
-                $this->error($inspection->getError());
-                $this->addSkipValidationCheckbox();
-                return false;
+        if (isset($this->config)) {
+            if ($this->config['type'] === 'ldap' && (
+                ! isset($data['skip_validation']) || $data['skip_validation'] == 0)
+            ) {
+                $self = clone $this;
+                $self->getSubForm('backend_form')->getElement('resource')->setIgnore(false);
+                $inspection = UserBackendConfigForm::inspectUserBackend($self);
+                if ($inspection && $inspection->hasError()) {
+                    $this->error($inspection->getError());
+                    $this->addSkipValidationCheckbox();
+                    return false;
+                }
             }
         }
 
@@ -177,7 +193,7 @@ class AuthBackendPage extends Form
 
             $inspection = UserBackendConfigForm::inspectUserBackend($self);
             if ($inspection !== null) {
-                $join = function ($e) use (& $join) {
+                $join = function ($e) use (&$join) {
                     return is_string($e) ? $e : join("\n", array_map($join, $e));
                 };
                 $this->addElement(
@@ -204,6 +220,8 @@ class AuthBackendPage extends Form
             }
 
             $this->info($this->translate('The configuration has been successfully validated.'));
+        } elseif (isset($formData['discovery_btn']) || isset($formData['btn_discover_domain'])) {
+            return parent::isValidPartial($formData);
         } elseif (! isset($formData['backend_validation'])) {
             // This is usually done by isValid(Partial), but as we're not calling any of these...
             $this->populate($formData);
@@ -229,4 +247,28 @@ class AuthBackendPage extends Form
             )
         );
     }
+
+    /**
+     * Get default values for the subform's elements suggested by a previous step
+     *
+     * @return string[]
+     */
+    public function getSuggestions()
+    {
+        return $this->suggestions;
+    }
+
+    /**
+     * Set default values for the subform's elements suggested by a previous step
+     *
+     * @param string[] $suggestions
+     *
+     * @return $this
+     */
+    public function setSuggestions(array $suggestions)
+    {
+        $this->suggestions = $suggestions;
+
+        return $this;
+    }
 }
