@@ -6,6 +6,7 @@ namespace Icinga\Module\Setup;
 use Icinga\Application\Platform;
 use Icinga\Module\Setup\Requirement\SetRequirement;
 use Icinga\Module\Setup\Requirement\WebLibraryRequirement;
+use InvalidArgumentException;
 use PDOException;
 use Icinga\Web\Form;
 use Icinga\Web\Wizard;
@@ -77,6 +78,12 @@ class WebWizard extends Wizard implements SetupWizard
         'UPDATE',
         'DELETE',
         'EXECUTE',
+        'CREATE',
+        'CREATE VIEW',
+        'ALTER',
+        'DROP',
+        'INDEX',
+        'USAGE', // PostgreSQL
         'TEMPORARY', // PostgreSql
         'CREATE TEMPORARY TABLES' // MySQL
     );
@@ -91,7 +98,8 @@ class WebWizard extends Wizard implements SetupWizard
         'icingaweb_group_membership',
         'icingaweb_user',
         'icingaweb_user_preference',
-        'icingaweb_rememberme'
+        'icingaweb_rememberme',
+        'icingaweb_schema'
     );
 
     /**
@@ -117,6 +125,7 @@ class WebWizard extends Wizard implements SetupWizard
         $this->addPage(new SummaryPage(array('name' => 'setup_summary')));
 
         if (($modulePageData = $this->getPageData('setup_modules')) !== null) {
+            /** @var ModulePage $modulePage */
             $modulePage = $this->getPage('setup_modules')->populate($modulePageData);
             foreach ($modulePage->getModuleWizards() as $moduleWizard) {
                 $this->addPage($moduleWizard);
@@ -133,6 +142,7 @@ class WebWizard extends Wizard implements SetupWizard
     public function setupPage(Form $page, Request $request)
     {
         if ($page->getName() === 'setup_requirements') {
+            /** @var RequirementsPage $page */
             $page->setWizard($this);
         } elseif ($page->getName() === 'setup_authentication_backend') {
             /** @var AuthBackendPage $page */
@@ -177,9 +187,11 @@ class WebWizard extends Wizard implements SetupWizard
                 . ' it is going to be created once the wizard is about to be finished.'
             ));
         } elseif ($page->getName() === 'setup_usergroup_backend') {
+            /** @var UserGroupBackendPage $page */
             $page->setResourceConfig($this->getPageData('setup_ldap_resource'));
             $page->setBackendConfig($this->getPageData('setup_authentication_backend'));
         } elseif ($page->getName() === 'setup_admin_account') {
+            /** @var AdminAccountPage $page */
             $page->setBackendConfig($this->getPageData('setup_authentication_backend'));
             $page->setGroupConfig($this->getPageData('setup_usergroup_backend'));
             $authData = $this->getPageData('setup_authentication_type');
@@ -189,6 +201,7 @@ class WebWizard extends Wizard implements SetupWizard
                 $page->setResourceConfig($this->getPageData('setup_ldap_resource'));
             }
         } elseif ($page->getName() === 'setup_auth_db_creation' || $page->getName() === 'setup_config_db_creation') {
+            /** @var DatabaseCreationPage $page */
             $page->setDatabaseSetupPrivileges(
                 array_unique(array_merge($this->databaseCreationPrivileges, $this->databaseSetupPrivileges))
             );
@@ -197,6 +210,7 @@ class WebWizard extends Wizard implements SetupWizard
                 $this->getPageData('setup_auth_db_resource') ?: $this->getPageData('setup_config_db_resource')
             );
         } elseif ($page->getName() === 'setup_summary') {
+            /** @var SummaryPage $page */
             $page->setSubjectTitle('Icinga Web 2');
             $page->setSummary($this->getSetup()->getSummary());
         } elseif ($page->getName() === 'setup_config_db_resource') {
@@ -276,7 +290,7 @@ class WebWizard extends Wizard implements SetupWizard
         if ($newPage->getName() === 'setup_auth_db_resource') {
             $authData = $this->getPageData('setup_authentication_type');
             $skip = $authData['type'] !== 'db';
-        } elseif ($newPage->getname() === 'setup_ldap_discovery') {
+        } elseif ($newPage->getName() === 'setup_ldap_discovery') {
             $authData = $this->getPageData('setup_authentication_type');
             $skip = $authData['type'] !== 'ldap';
         /*} elseif ($newPage->getName() === 'setup_ldap_discovery_confirm') {
@@ -553,7 +567,9 @@ class WebWizard extends Wizard implements SetupWizard
             }
         }
 
-        $setup->addStep(new EnableModuleStep(array_keys($this->getPage('setup_modules')->getCheckedModules())));
+        /** @var ModulePage $setupPage */
+        $setupPage = $this->getPage('setup_modules');
+        $setup->addStep(new EnableModuleStep(array_keys($setupPage->getCheckedModules())));
 
         return $setup;
     }
@@ -586,7 +602,7 @@ class WebWizard extends Wizard implements SetupWizard
         )));
 
         $set->add(new WebLibraryRequirement(array(
-            'condition'     => ['icinga-php-library', '>=', '0.9.0'],
+            'condition'     => ['icinga-php-library', '>=', '0.13.0'],
             'alias'         => 'Icinga PHP library',
             'description'   => mt(
                 'setup',
@@ -595,7 +611,7 @@ class WebWizard extends Wizard implements SetupWizard
         )));
 
         $set->add(new WebLibraryRequirement(array(
-            'condition'     => ['icinga-php-thirdparty', '>=', '0.11.0'],
+            'condition'     => ['icinga-php-thirdparty', '>=', '0.12.0'],
             'alias'         => 'Icinga PHP Thirdparty',
             'description'   => mt(
                 'setup',
